@@ -1,7 +1,7 @@
 #!/usr/bin/env seed
 
-imports.gi.versions.Clutter = "0.9";
-imports.gi.versions.GtkClutter = "0.9";
+imports.gi.versions.Clutter = "1.0";
+imports.gi.versions.GtkClutter = "1.0";
 
 Clutter = imports.gi.Clutter;
 Gtk = imports.gi.Gtk;
@@ -396,9 +396,6 @@ window.resize(600, 600);
 window.add(vbox);
 window.show_all();
 
-// Ask Clutter to return motion events at 60Hz to help make dragging smoother
-Clutter.set_motion_events_frequency(60);
-
 load_actors();
 stage.show_all();
 
