@@ -1,3 +1,5 @@
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
+
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
  *
@@ -12,7 +14,7 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #include "seed-private.h"
@@ -32,8 +34,7 @@
  *
  */
 void
-seed_value_protect (JSContextRef ctx,
-		    JSValueRef value)
+seed_value_protect (JSContextRef ctx, JSValueRef value)
 {
   JSValueProtect (ctx, value);
 }
@@ -48,8 +49,7 @@ seed_value_protect (JSContextRef ctx,
  *
  */
 void
-seed_value_unprotect (JSContextRef ctx,
-		      JSValueRef value)
+seed_value_unprotect (JSContextRef ctx, JSValueRef value)
 {
   JSValueUnprotect (ctx, value);
 }
@@ -69,8 +69,7 @@ seed_value_unprotect (JSContextRef ctx,
  *
  */
 JSGlobalContextRef
-seed_context_create (JSContextGroupRef group,
-		     JSClassRef global_class)
+seed_context_create (JSContextGroupRef group, JSClassRef global_class)
 {
   return JSGlobalContextCreateInGroup (group, global_class);
 }
@@ -103,19 +102,6 @@ seed_context_unref (JSGlobalContextRef ctx)
   JSGlobalContextRelease (ctx);
 }
 
-/**
- * seed_make_null:
- * @ctx: A #SeedContext.
- *
- * Return value: A #SeedValue representing %NULL.
- *
- */
-JSValueRef
-seed_make_null (JSContextRef ctx)
-{
-  return JSValueMakeNull (ctx);
-}
-
 /**
  * seed_make_object:
  * @ctx: The #SeedContext in which to create the new object.
@@ -127,9 +113,7 @@ seed_make_null (JSContextRef ctx)
  *
  */
 JSObjectRef
-seed_make_object (JSContextRef ctx,
-		  JSClassRef class,
-		  gpointer private)
+seed_make_object (JSContextRef ctx, JSClassRef class, gpointer private)
 {
   return JSObjectMake (ctx, class, private);
 }
@@ -158,8 +142,7 @@ seed_object_set_property_at_index (JSContextRef ctx,
 JSValueRef
 seed_object_get_property_at_index (JSContextRef ctx,
 				   JSObjectRef object,
-				   gint index,
-				   JSValueRef * exception)
+				   gint index, JSValueRef * exception)
 {
   return JSObjectGetPropertyAtIndex (ctx, object, index, exception);
 }
@@ -203,14 +186,16 @@ seed_object_call (JSContextRef ctx,
  * Creates a new #SeedScript instance with @js as the contents, then
  * checks for proper syntax.
  *
+ * Note: seed_make_script() does not handle the shebang line, and will return a
+ *       parse error if one is included in @js.
+ *
  * Return value: The newly created #SeedScript.
  *
  */
 SeedScript *
 seed_make_script (JSContextRef ctx,
 		  const gchar * js,
-		  const gchar * source_url,
-		  gint line_number)
+		  const gchar * source_url, gint line_number)
 {
   SeedScript *ret = g_new0 (SeedScript, 1);
 
@@ -242,8 +227,7 @@ seed_make_script (JSContextRef ctx,
  *
  */
 SeedScript *
-seed_script_new_from_file (JSContextRef ctx,
-			   gchar * file)
+seed_script_new_from_file (JSContextRef ctx, gchar * file)
 {
   SeedScript *script;
   GError *e = NULL;
@@ -272,9 +256,7 @@ seed_script_new_from_file (JSContextRef ctx,
  *
  */
 JSValueRef
-seed_evaluate (JSContextRef ctx,
-	       SeedScript * s,
-	       JSObjectRef this)
+seed_evaluate (JSContextRef ctx, SeedScript * s, JSObjectRef this)
 {
   JSValueRef ret;
 
@@ -292,15 +274,15 @@ seed_evaluate (JSContextRef ctx,
  * @source: A string representing the JavaScript to evaluate.
  * @exception: A #SeedException pointer to store an exception in.
  *
- * Evaluates a string of JavaScript.
+ * Evaluates a string of JavaScript in @ctx; if an exception
+ * is raised in the context of the script, it will be placed in @exception.
  *
  * Return value: The #SeedValue returned by evaluating the script.
  *
  */
 JSValueRef
 seed_simple_evaluate (JSContextRef ctx,
-		      const gchar * source,
-		      JSValueRef *exception)
+		      const gchar * source, JSValueRef * exception)
 {
   JSValueRef ret;
   JSStringRef script = JSStringCreateWithUTF8CString (source);
@@ -315,7 +297,9 @@ seed_simple_evaluate (JSContextRef ctx,
  * seed_script_exception:
  * @s: A #SeedScript.
  *
- * Return value: A #JSValueRef representing the exception of @s.
+ * Retrieves the exception (if any) raised during the evaluation of @s.
+ *
+ * Return value: A #SeedException representing the exception of @s.
  *
  */
 JSValueRef
@@ -412,6 +396,15 @@ seed_string_unref (JSStringRef string)
   JSStringRelease (string);
 }
 
+void
+seed_script_destroy (SeedScript * s)
+{
+  seed_string_unref (s->script);
+  seed_string_unref (s->source_url);
+
+  g_free (s);
+}
+
 // TODO:FIXME: Do we have an external typedef or anything for JSClassDefinition?
 
 /**
@@ -452,6 +445,8 @@ seed_make_constructor (JSContextRef ctx,
  * seed_object_get_private:
  * @object: A #SeedObject.
  *
+ * Retrieves the private data of @object.
+ *
  * Return value: A pointer to the private data of @object.
  *
  */
@@ -480,7 +475,9 @@ seed_object_set_private (JSObjectRef object, gpointer value)
  * @ctx: A #SeedContext.
  * @value: A #SeedValue.
  *
- * Return value: #true if @value represents %NULL, #false otherwise.
+ * Determine whether or not @value represents the JavaScript null value
+ *
+ * Return value: A #gboolean (%true if @value is 'null')
  *
  */
 gboolean
@@ -489,6 +486,16 @@ seed_value_is_null (JSContextRef ctx, JSValueRef value)
   return JSValueIsNull (ctx, value);
 }
 
+/**
+ * seed_value_is_undefined:
+ * @ctx: A #SeedContext.
+ * @value: A #SeedValue.
+ *
+ * Determine whether or not @value represents the JavaScript undefined value
+ *
+ * Return value: A #gboolean (%true if @value is 'undefined')
+ *
+ */
 gboolean
 seed_value_is_undefined (JSContextRef ctx, JSValueRef value)
 {
@@ -500,7 +507,9 @@ seed_value_is_undefined (JSContextRef ctx, JSValueRef value)
  * @ctx: A #SeedContext.
  * @value: A #SeedValue.
  *
- * Return value: #true if @value is an object, #false otherwise.
+ * Determine whether or not @value is a JavaScript object
+ *
+ * Return value: A #gboolean (%true if @value is an object)
  *
  */
 gboolean
@@ -515,22 +524,28 @@ seed_value_is_object (JSContextRef ctx, JSValueRef value)
  * @value: A #SeedValue.
  * @klass: A #SeedClass.
  *
- * Return value: #true if @value is an object of specified class, #false otherwise.
+ * Determine whether or not @value is an object of the specified class
+ *
+ * Return value: A #gboolean (%true if @value is of class @klass)
  *
  */
 gboolean
-seed_value_is_object_of_class (JSContextRef ctx, JSValueRef value, JSClassRef klass)
+seed_value_is_object_of_class (JSContextRef ctx, JSValueRef value,
+			       JSClassRef klass)
 {
-  return !seed_value_is_null (ctx, value) && JSValueIsObjectOfClass (ctx, value, klass);
+  return !seed_value_is_null (ctx, value)
+    && JSValueIsObjectOfClass (ctx, value, klass);
 }
 
 /**
  * seed_value_is_function:
  * @ctx: A #SeedContext.
- * @value: A #SeedObject.
+ * @value: A #SeedValue.
  *
- * Return value: #true if @value is a function (and therefore, an object),
- *               #false otherwise.
+ * Determine whether or not @value is a JavaScript function (and, therefore,
+ * an object)
+ *
+ * Return value: A #gboolean (%true if @value is a function)
  *
  */
 gboolean
@@ -544,7 +559,9 @@ seed_value_is_function (JSContextRef ctx, JSObjectRef value)
  * @ctx: A #SeedContext.
  * @value: A #SeedValue.
  *
- * Return value: #true if @value is a string, and #false otherwise.
+ * Determine whether or not @value is a JavaScript string
+ *
+ * Return value: A #gboolean (%true if @value is a string)
  *
  */
 gboolean
@@ -558,7 +575,9 @@ seed_value_is_string (JSContextRef ctx, JSValueRef value)
  * @ctx: A #SeedContext.
  * @value: A #SeedValue.
  *
- * Return value: #true if @value is a number), #false otherwise.
+ * Determine whether or not @value is a JavaScript number
+ *
+ * Return value: A #gboolean (%true if @value is a number)
  *
  */
 gboolean
@@ -606,15 +625,18 @@ seed_engine_get_search_path (SeedEngine * eng)
  * @signal: A signal specification.
  * @function: The JavaScript function to connect to the signal.
  * @user_data: An additional parameter to pass to the function.
+ *
+ * Connects @function to the signal specified by @signal on @object. @user_data
+ * is passed as the user_data argument to the callback function.
+ *
  */
 void
 seed_signal_connect_full (JSContextRef ctx,
-			   GObject *object,
-			   const gchar *signal,
-			   JSObjectRef function,
-			   JSObjectRef user_data)
+			  GObject * object,
+			  const gchar * signal,
+			  JSObjectRef function, JSObjectRef user_data)
 {
-  seed_gobject_signal_connect(ctx, signal, object, function,
+  seed_gobject_signal_connect (ctx, signal, object, function,
 			       NULL, user_data);
 }
 
@@ -623,19 +645,22 @@ seed_signal_connect_full (JSContextRef ctx,
  * @ctx: A valid #SeedContext
  * @object: A #GObject, to connect the signal on.
  * @signal: A signal specification.
- * @script: The script to connect to the signal. Should be a function.
+ * @script: The script to connect to the signal. Should return a function.
+ *
+ * Evaluates @script, which should return a function, then connects the returned
+ * function to the signal specified by @signal on @object. @user_data
+ * is passed as the user_data argument to the callback function.
+ *
  */
 void
 seed_signal_connect (JSContextRef ctx,
-		     GObject *object,
-		     const gchar *signal,
-		     const gchar *script)
+		     GObject * object,
+		     const gchar * signal, const gchar * script)
 {
   JSValueRef func;
 
-  func = seed_simple_evaluate(ctx, script, NULL);
-  seed_signal_connect_full(ctx, object, signal, (JSObjectRef)func,
-			   NULL);
+  func = seed_simple_evaluate (ctx, script, NULL);
+  seed_signal_connect_full (ctx, object, signal, (JSObjectRef) func, NULL);
 }
 
 /**
@@ -647,7 +672,7 @@ seed_signal_connect (JSContextRef ctx,
 JSObjectRef
 seed_context_get_global_object (JSGlobalContextRef ctx)
 {
-  return JSContextGetGlobalObject(ctx);
+  return JSContextGetGlobalObject (ctx);
 }
 
 
@@ -659,24 +684,43 @@ seed_context_get_global_object (JSGlobalContextRef ctx)
  * @exception: A #SeedException in which to store an exception.
  *             Pass %NULL to ignore exceptions.
  *
+ * Creates a JavaScript Array object from @elements, a C-style array of
+ * SeedValues.
+ *
  * Return value: A new array object, populated with @elements.
  */
 
 JSObjectRef
 seed_make_array (JSContextRef ctx,
 		 const JSValueRef elements[],
-		 gsize num_elements,
-		 JSValueRef *exception)
+		 gsize num_elements, JSValueRef * exception)
 {
   return JSObjectMakeArray (ctx, num_elements, elements, exception);
 }
 
+/**
+ * seed_make_null:
+ * @ctx: A valid #SeedContext
+ *
+ * Note that this function returns a valid SeedValue,
+ * representing the null JavaScript value, and not a
+ * null SeedValue.
+ *
+ * Return value: A #SeedValue of the 'null' type.
+ *
+ */
+JSValueRef
+seed_make_null (JSContextRef ctx)
+{
+  return JSValueMakeNull (ctx);
+}
+
 /**
  * seed_make_undefined:
  * @ctx: A valid #SeedContext
  *
  * Note that this function returns a valid SeedValue,
- * representing the undefined javascript value, and not an
+ * representing the undefined JavaScript value, and not an
  * undefined SeedValue.
  *
  * Return value: A #SeedValue of the 'undefined' type.
@@ -695,8 +739,7 @@ seed_make_undefined (JSContextRef ctx)
  * Return value: The type of @value
  */
 JSType
-seed_value_get_type (JSContextRef ctx,
-		     JSValueRef value)
+seed_value_get_type (JSContextRef ctx, JSValueRef value)
 {
   return JSValueGetType (ctx, value);
 }
@@ -709,24 +752,23 @@ seed_value_get_type (JSContextRef ctx,
  * Return value: A %NULL terminated array containing the property names of @object
  */
 gchar **
-seed_object_copy_property_names(JSContextRef ctx,
-				JSObjectRef object)
+seed_object_copy_property_names (JSContextRef ctx, JSObjectRef object)
 {
   JSPropertyNameArrayRef names;
+  JSStringRef name;
   guint i, length;
+  gsize max_length;
+  gchar *c_name;
   gchar **ret;
 
   names = JSObjectCopyPropertyNames (ctx, object);
   length = JSPropertyNameArrayGetCount (names);
-  ret = g_malloc((length+1)*sizeof(gchar *));
+  ret = (gchar **) g_malloc ((length + 1) * sizeof (gchar *));
   for (i = 0; i < length; i++)
     {
-      JSStringRef name = JSPropertyNameArrayGetNameAtIndex (names, i);
-      guint max_length;
-      gchar *c_name;
-
+      name = JSPropertyNameArrayGetNameAtIndex (names, i);
       max_length = JSStringGetMaximumUTF8CStringSize (name);
-      c_name = g_malloc (max_length * sizeof (gchar));
+      c_name = (gchar *) g_malloc (max_length * sizeof (gchar));
       JSStringGetUTF8CString (name, c_name, length);
       ret[i] = c_name;
 
@@ -762,12 +804,13 @@ seed_object_is_of_class (JSContextRef ctx, JSObjectRef obj, JSClassRef class)
  * @func: A #SeedFunctionCallback to implement the function.
  * @name: The name of the function (used in exceptions).
  *
- * Return value: The function
+ * Creates a JavaScript object representing a first-class function; when
+ * the function is called from JavaScript, @func will be called.
+ *
+ * Return value: A #SeedObject representing the function
  */
 JSObjectRef
-seed_make_function (JSContextRef ctx,
-		    gpointer func,
-		    gchar *name)
+seed_make_function (JSContextRef ctx, gpointer func, gchar * name)
 {
   JSObjectRef oref;
   JSStringRef jsname = NULL;
@@ -806,10 +849,8 @@ seed_make_function (JSContextRef ctx,
  */
 gboolean
 seed_value_to_format (JSContextRef ctx,
-		      const gchar *format,
-		      JSValueRef *values,
-		      JSValueRef *exception,
-		      ...)
+		      const gchar * format,
+		      JSValueRef * values, JSValueRef * exception, ...)
 {
   va_list argp;
   const gchar *c;
@@ -833,32 +874,32 @@ seed_value_to_format (JSContextRef ctx,
 	{
 	case 'i':
 	  {
-	    *((gint *)p) = seed_value_to_int (ctx, val, exception);
+	    *((gint *) p) = seed_value_to_int (ctx, val, exception);
 	    break;
 	  }
 	case 'u':
 	  {
-	    *((guint *)p) = seed_value_to_uint (ctx, val, exception);
+	    *((guint *) p) = seed_value_to_uint (ctx, val, exception);
 	    break;
 	  }
 	case 's':
 	  {
-	    *((gchar **)p) = seed_value_to_string (ctx, val, exception);
+	    *((gchar **) p) = seed_value_to_string (ctx, val, exception);
 	    break;
 	  }
 	case 'f':
 	  {
-	    *((gdouble *)p) = seed_value_to_int (ctx, val, exception);
+	    *((gdouble *) p) = seed_value_to_int (ctx, val, exception);
 	    break;
 	  }
 	case 'o':
 	  {
-	    *((GObject **)p) = seed_value_to_object (ctx, val, exception);
+	    *((GObject **) p) = seed_value_to_object (ctx, val, exception);
 	    break;
 	  }
 	case 'c':
 	  {
-	    *((gchar *)c) = seed_value_to_char (ctx, val, exception);
+	    *((gchar *) c) = seed_value_to_char (ctx, val, exception);
 	    break;
 	  }
 	}
@@ -869,3 +910,20 @@ seed_value_to_format (JSContextRef ctx,
   return TRUE;
 }
 
+/*************************** CALLBACK DOCUMENTATION **************************/
+
+/**
+ * SeedFunctionCallback:
+ * @ctx: A #SeedContext
+ * @function: The #SeedObject representing the function
+ * @this_object: The #SeedObject representing the "this" object in the caller
+ * @argument_count: The number of arguments passed into the callback
+ * @arguments: An array of #SeedValues; the value of the arguments passed in
+ * @exception: A reference to a #SeedException; use seed_make_exception() in order
+ *             to throw a JavaScript exception from the callback.
+ *
+ * All native C function callbacks should use the prototype of
+ * SeedFunctionCallback.
+ *
+ * Return value: The #SeedValue to return to the caller
+ */
