@@ -1,6 +1,4 @@
-/*
- * -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*-
- */
+/* -*- mode: C; indent-tabs-mode: t; tab-width: 8; c-basic-offset: 2; -*- */
 
 /*
  * This file is part of Seed, the GObject Introspection<->Javascript bindings.
@@ -16,7 +14,7 @@
  * You should have received a copy of the GNU Lesser General Public License
  * along with Seed.  If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) Robert Carr 2008 <carrr@rpi.edu>
+ * Copyright (C) Robert Carr 2009 <carrr@rpi.edu>
  */
 
 #include <glib.h>
@@ -88,6 +86,7 @@ SeedScript *seed_make_script (SeedContext ctx,
 			      gint line_number);
 SeedScript *seed_script_new_from_file (SeedContext ctx, gchar * file);
 SeedException seed_script_exception (SeedScript * s);
+void seed_script_destroy (SeedScript *s);
 void seed_make_exception (SeedContext ctx, SeedException exception,
 			  const gchar * name, const gchar * message, ...) G_GNUC_PRINTF (4,5);
 gchar *seed_exception_get_name (SeedContext ctx, SeedException exception);
@@ -107,15 +106,18 @@ SeedGlobalContext seed_context_create (SeedContextGroup group,
 SeedGlobalContext seed_context_ref (SeedGlobalContext ctx);
 void seed_context_unref (SeedGlobalContext ctx);
 
+SeedObject seed_context_get_global_object (SeedContext ctx);
+
+void seed_importer_add_global(SeedContext ctx, gchar *name);
+void seed_importer_set_search_path (SeedContext ctx,
+				    gchar **search_path);
+void seed_prepare_global_context (SeedContext ctx);
+
+
+
 SeedValue seed_make_null (SeedContext ctx);
 SeedValue seed_make_undefined (SeedContext ctx);
 
-SeedObject seed_make_object (SeedContext ctx, SeedClass class,
-			     gpointer private);
-
-gpointer seed_object_get_private (SeedObject object);
-void seed_object_set_private (SeedObject object, gpointer value);
-
 SeedString seed_string_ref (SeedString string);
 void seed_string_unref (SeedString string);
 
@@ -134,34 +136,8 @@ gboolean seed_value_is_function (SeedContext ctx, SeedObject value);
 gboolean seed_value_is_string (SeedContext ctx, SeedValue value);
 gboolean seed_value_is_number (SeedContext ctx, SeedValue value);
 
-SeedValue seed_object_call (SeedContext ctx,
-			    SeedObject object,
-			    SeedObject this,
-			    gsize argument_count,
-			    const SeedValue arguments[],
-			    SeedException * exception);
-
 void seed_value_unprotect (SeedContext ctx, SeedValue value);
 void seed_value_protect (SeedContext ctx, SeedValue value);
-/*
- * seed-types.c
- */
-gboolean seed_object_set_property (SeedContext ctx,
-				   SeedObject object,
-				   const gchar * name, SeedValue value);
-SeedValue seed_object_get_property (SeedContext ctx,
-				    SeedObject object, const gchar * name);
-
-void seed_object_set_property_at_index (SeedContext ctx,
-					SeedObject object,
-					gint index,
-					SeedValue value,
-					SeedException * exception);
-
-SeedValue seed_object_get_property_at_index (SeedContext ctx,
-					     SeedObject object,
-					     gint index,
-					     SeedException *exception);
 
 gboolean seed_value_to_boolean (SeedContext ctx,
 				SeedValue val, SeedException * exception);
@@ -227,17 +203,71 @@ SeedValue seed_value_from_string (SeedContext ctx,
 				  const gchar * val, SeedException * exception);
 
 gchar *seed_value_to_filename (SeedContext ctx,
-			       SeedValue val, SeedValue * exception);
+			       SeedValue val, SeedValue *exception);
 SeedValue seed_value_from_filename (SeedContext ctx,
-				    const gchar * filename,
-				    SeedValue * exception);
+				    SeedValue val, SeedValue *exception);
+
+SeedValue seed_value_from_binary_string (SeedContext ctx,
+					 const gchar *bytes,
+					 gint n_bytes, 
+					 SeedException *exception);
+
+SeedType seed_value_get_type (SeedContext ctx, SeedValue value);
+
+gboolean
+seed_value_to_format (SeedContext ctx,
+		      const gchar *format,
+		      SeedValue *values,
+		      SeedValue *exception,
+		      ...);
+
+typedef SeedObject (*SeedModuleInitCallback) (SeedEngine * eng);
+
+gboolean seed_object_set_property (SeedContext ctx,
+				   SeedObject object,
+				   const gchar * name, SeedValue value);
+SeedValue seed_object_get_property (SeedContext ctx,
+				    SeedObject object, const gchar * name);
+
+void seed_object_set_property_at_index (SeedContext ctx,
+					SeedObject object,
+					gint index,
+					SeedValue value,
+					SeedException * exception);
+
+SeedValue seed_object_get_property_at_index (SeedContext ctx,
+					     SeedObject object,
+					     gint index,
+					     SeedException *exception);
+
+SeedValue seed_object_call (SeedContext ctx,
+			    SeedObject object,
+			    SeedObject this,
+			    gsize argument_count,
+			    const SeedValue arguments[],
+			    SeedException * exception);
 
 GObject *seed_value_to_object (SeedContext ctx,
 			       SeedValue val, SeedException * exception);
 SeedValue seed_value_from_object (SeedContext ctx,
 				  GObject * val, SeedException * exception);
 
+SeedObject seed_make_object (SeedContext ctx, SeedClass class,
+			     gpointer private);
+
+gpointer seed_object_get_private (SeedObject object);
+void seed_object_set_private (SeedObject object, gpointer value);
+
+gchar **seed_object_copy_property_names(SeedContext ctx, SeedObject object);
+
 gpointer seed_pointer_get_pointer (SeedContext ctx, SeedValue pointer);
+
+SeedObject
+seed_object_get_prototype (SeedContext ctx, SeedObject obj);
+
+gboolean
+seed_object_is_of_class (SeedContext ctx, SeedObject obj, SeedClass class);
+
 SeedValue seed_make_pointer (SeedContext ctx, gpointer pointer);
 
 typedef SeedValue (*SeedFunctionCallback) (SeedContext ctx,
@@ -248,14 +278,15 @@ typedef SeedValue (*SeedFunctionCallback) (SeedContext ctx,
 					   SeedException * exception);
 
 void seed_create_function (SeedContext ctx,
-			   gchar * name, SeedFunctionCallback callback,
-			   SeedObject object);
+			   gchar * name, SeedFunctionCallback func,
+			   SeedObject obj);
 SeedObject seed_make_function (SeedContext ctx, SeedFunctionCallback func, const gchar *name);
-/* Inconsistent naming? */
+
+
 SeedObject seed_make_array (SeedContext ctx, const SeedValue elements,
 			    gsize num_elements, SeedException *exception);
 
-typedef SeedObject (*SeedModuleInitCallback) (SeedEngine * eng);
+
 
 typedef void (*SeedObjectInitializeCallback) (SeedContext ctx,
 					      SeedObject object);
@@ -379,30 +410,12 @@ seed_signal_connect_value (SeedContext ctx,
 			   SeedValue function,
 			   SeedValue user_data);
 
-
-SeedObject seed_context_get_global_object (SeedContext ctx);
-
-void seed_importer_add_global(SeedContext ctx, gchar *name);
-void seed_importer_set_search_path (SeedContext ctx,
-				    gchar **search_path);
-
-void seed_prepare_global_context (SeedContext ctx);
-
-SeedType seed_value_get_type (SeedContext ctx, SeedValue value);
-
-gchar **seed_object_copy_property_names(SeedContext ctx, SeedObject object);
-
-SeedValue
-seed_value_from_binary_string (SeedContext ctx,
-			       const gchar *bytes,
-			       gint n_bytes,
-			       SeedException *exception);
-
 GClosure *seed_closure_new (SeedContext ctx,
 			    SeedObject function,
 			    SeedObject user_data,
 			    const gchar *description);
 
+
 SeedObject
 seed_closure_get_callable (GClosure *c);
 
@@ -415,17 +428,5 @@ seed_closure_invoke_with_context (SeedContext ctx, GClosure *closure, SeedValue
 void
 seed_closure_warn_exception (GClosure *c, SeedContext ctx, SeedException exception);
 
-SeedObject
-seed_object_get_prototype (SeedContext ctx, SeedObject obj);
-
-gboolean
-seed_object_is_of_class (SeedContext ctx, SeedObject obj, SeedClass class);
-
-gboolean
-seed_value_to_format (SeedContext ctx,
-		      const gchar *format,
-		      SeedValue *values,
-		      SeedValue *exception,
-		      ...);
 
 #endif
