@@ -1,7 +1,7 @@
 #!/usr/bin/env seed
 // Returns: 0
 // STDIN:
-// STDOUT:1\n-124\n129\n-1235\n1387\n-123435\n133487\n-16323375\n13873737\n-16325\n33737\n-16325\n33737\n12\n143\n-1853\.12329101562\n-134543853\.12334\n8\n\["åäö","\/etc\/fstab"\]\n\["1","2","3"\]\n\["1","2","3"\]\n\["1","2","3"\]\n\["1","2","3"\]\n1,2,3\n5\n0\n123\n0\n1\n42\n1\n4\n15\n120\n120\.2357\n42\n19
+// STDOUT:1\n-124\n129\n-1235\n1387\n-123435\n133487\n-16323375\n13873737\n-16325\n33737\n-16325\n33737\n12\n143\n-1853\.12329101562\n-134543853\.12334\n8\n\["åäö","\/etc\/fstab"\]\n\["1","2","3"\]\n\["1","2","3"\]\n\["1","2","3"\]\n\["1","2","3"\]\nthanks,for,all,the,fish\n5\n0\n123\n0\n1\n42\n1\n2\n4\n15\n120\n120\.2357\n42\n19
 // STDERR:
 
 Everything = imports.gi.Everything;
@@ -52,7 +52,7 @@ print(TestEnum.VALUE2);
 print(TestEnum.VALUE3);
 print(TestFlags.FLAG1);
 print(TestFlags.FLAG2);
-// Err.... wot? The gir has 2 in twice... print(TestFlags.Flag3);
+print(TestFlags.FLAG3);
 
 TestStructA.some_int = 15;
 print(TestStructA.some_int);
